@@ -5,6 +5,7 @@ pub mod die;
 pub mod hide;
 pub mod bx;
 pub mod s;
+pub mod map;
 
 pub use {
     typer::*,
@@ -14,4 +15,5 @@ pub use {
     hide::*,
     bx::*,
     s::*,
+    map::*,
 };
